# Credits

Copyright (c) 2024 Centre National d'Etudes Spatiales (CNES).

Pandora plugin LibSGM is licensed under permissive Apache 2 license (See LICENSE file).
The copyright is kept CNES only for long term maintenance ease.

See CONTRIBUTING.md for more details on Contributor License Agreement.

This file keeps track of authors contributions.

## Development Lead

* Emmanuelle Sarrazin <emmanuelle.sarrazin@cnes.fr>
* Natalia Jimenez <natalia.jimenez-diaz@csgroup.eu>
* Alice de Bardonnèche-Richard <alice.de-bardonneche-richard@csgroup.eu>
* Marie Leconte <marie.leconte@csgroup.eu>
* Elisa Duz <elisa.duz@csgroup.eu>
* Philippe Mallet-Ladeira <philippe.mallet-ladeira@csgroup.eu>

## Contributors

* Veronique Defonte <veronique.defonte@csgroup.eu>
* Quentin Fardet <quentin.fardet@csgroup.eu>
* Mannaïg L'Haridon <mannaig.lharidon@csgroup.eu>
* Julien Michel <Julien.Michel@cnes.fr>
* Yoann Steux <yoann.steux@csgroup.eu>
* Mathis Roux <mathis.roux@csgroup.eu>
* David Youssefi <David.Youssefi@cnes.fr>
* Roman Malinowski <roman.malinowski@hds.utc.fr>

Update here with new contributors.

## Original Developers/Designers/Supporters

* Myriam Cournet <myriam.cournet@cnes.fr>
* Quentin Fardet <quentin.fardet@csgroup.eu>
* Emmanuelle Sarrazin <emmanuelle.sarrazin@cnes.fr>
* Loïc Dumas <loic.dumas@csgroup.eu>
